@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -394,7 +394,7 @@ public class CurrencyNames_zh_Hant extends OpenListResourceBundle {
             { "brb", "\u5df4\u897f\u514b\u9b6f\u85a9\u591a\u8fb2\u74e6 (1967\u20131986)" },
             { "brc", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1986\u20131989)" },
             { "bre", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1990\u20131993)" },
-            { "brl", "\u5df4\u897f\u91cc\u62c9" },
+            { "brl", "\u5df4\u897f\u96f7\u4e9e\u723e" },
             { "brn", "\u5df4\u897f\u514b\u5982\u723e\u9054\u8fb2\u74e6" },
             { "brr", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1993\u20131994)" },
             { "brz", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1942 \u20131967)" },
@@ -591,8 +591,8 @@ public class CurrencyNames_zh_Hant extends OpenListResourceBundle {
             { "tnd", "\u7a81\u5c3c\u897f\u4e9e\u7b2c\u7d0d\u723e" },
             { "top", "\u6771\u52a0\u6f58\u52a0" },
             { "tpe", "\u5e1d\u6c76\u57c3\u65af\u5eab\u591a" },
-            { "trl", "\u571f\u8033\u5176\u91cc\u62c9" },
-            { "try", "\u65b0\u571f\u8033\u5176\u91cc\u62c9" },
+            { "trl", "\u571f\u8033\u5176\u91cc\u62c9 (1922\u20132005)" },
+            { "try", "\u571f\u8033\u5176\u91cc\u62c9" },
             { "ttd", "\u5343\u91cc\u9054\u53ca\u6258\u5df4\u54e5\u5143" },
             { "twd", "\u65b0\u53f0\u5e63" },
             { "tzs", "\u5766\u5c1a\u5c3c\u4e9e\u5148\u4ee4" },
